[][src]Struct subscript::view_sys::runtime::css::hashids::HashIds

pub struct HashIds { /* fields omitted */ }

Methods

impl HashIds[src]

pub fn new() -> Self[src]

Create a new HashIds instance

pub fn with_salt(salt: &str) -> Self[src]

Create a new HashIds instance with the specified salt.

This is a convenience function, which is equivalent to:

use hashids::HashIdsBuilder
HashIdsBuilder::new().salt(salt).build()

except always returning success.

pub fn decode(&self, hash: &str) -> Option<Vec<u64>>[src]

Restore a list of numbers from the passed hash

If the hash is corrupt, return None

pub fn encode(&self, numbers: &[u64]) -> String[src]

Builds a hash from the passed numbers